Banditcoot
====================

<img align="left" width="75" src="https://github.com/dan-kwon/banditcoot/blob/master/resources/Banditcoot.png"/> 

**banditcoot** is a Python module is intended for my own personal use when developing and testing multi-armed bandit algorithms. Forked from the accompanying [code repository](https://github.com/johnmyleswhite/BanditsBook) for [Bandit Algorithms for Website Optimization](https://www.oreilly.com/library/view/bandit-algorithms-for/9781449341565/).

*Any use of this code is at your own risk.*
</br>

## Installation
--------------------
Recommended method of installation is to use pip 
```
pip install banditcoot
```


## Quickstart
--------------------
